/// <reference types="node" />
/// <reference types="jszip" />
import * as JSZip from 'jszip';
import { FiwoFile } from './file';
import { LastIndexOfTagParams } from './xml-parser/last-index-of-tag';
import * as textDecoder from './text-decoder';
import { TagAttributesGetParams, TagAttributesParserState } from './xml-parser/get-tag-attributes';
import { TagTextContentParams, TagTextContentParserState } from './xml-parser/get-tag-text-content';
export * from './file';
export * from './reader';
export * from './writer';
export * from './binary';
export declare const xmlParser: {
    lastIndexOfTag: (params: LastIndexOfTagParams) => number;
    getTagAttributes: (params: TagAttributesGetParams) => TagAttributesParserState;
    getTagTextContent: (params: TagTextContentParams) => TagTextContentParserState;
};
export { LastIndexOfTagParams, TagAttributesGetParams, TagTextContentParams, TagTextContentParserState, TagAttributesParserState, textDecoder };
export declare type FileBuffer = ArrayBuffer | Buffer;
export declare type IncomingFile = File | Blob | FileBuffer;
export declare type IncomingFileContent = Uint8Array | Buffer;
export interface FiwoDocument extends FiwoFile {
}
export interface FiwoPresentation extends FiwoFile {
}
export interface FiwoSpreadsheet extends FiwoFile {
}
export interface IncomingData {
    fileBuffer: FileBuffer;
    fileContent: IncomingFileContent;
}
export interface ArchiveEntry extends JSZipObject {
    [key: string]: any;
}
export interface Archive extends JSZip {
    files: {
        [key: string]: ArchiveEntry;
    };
    [key: string]: any;
}
export declare type ArchiveEntrySerialization = Serialization;
export declare function readArchive(fileContent: IncomingFileContent): Promise<Archive>;
